#
# spec file for package openh323
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#
%define DISTRIBUTABLE 1
#
%ifarch %ix86
%define arch x86
%else
%define arch %{_target_cpu}
%endif

Name:           openh323
Summary:        An Open Source ITU H.323 Library and Sample Application
License:        MPL-1.0
Group:          System/Libraries
Version:        1.19.0.1
Release:        3.2
%define _version 1_19_0_1
Url:            http://openh323.sourceforge.net/
Source:         openh323-v%{_version}-src-tar.bz2
Patch:          openh323_v1_19_0_1.diff
Patch1:         openh323-system-amrnb.diff
Patch2:         openh323-incl.diff
Patch3:         openh323-SHAREDLIBEXT.diff
Patch4:         openh323-OPTCCFLAGS.patch
Patch5:         patches/openh323-nonat_ptrace
Patch6:         openh323.linux-compiler.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  SDL-devel
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libdv
BuildRequires:  libgsm-devel
BuildRequires:  openldap2-devel
BuildRequires:  pwlib-devel = 1.11.0
BuildRequires:  speex-devel
%if %DISTRIBUTABLE == 0
BuildRequires:  amrnb-devel
%endif

%description
The OpenH323 project aims to create a full featured, interoperable, and
open source implementation of the ITU H.323 teleconferencing protocol
that can be used by personal developers and commercial users without
charge.

OpenH323 development is coordinated by an Australian company,
Equivalence Pty Ltd (http://www.equival.com), but is open to any
interested party. Commercial and private use of the OpenH323 code,
including use in commercial products and resale, is encouraged through
use of the MPL (Mozilla Public license).


%package devel
Summary:        OpenH323 Library for developers
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       pwlib-devel = 1.11.0
# Suggest debugsource file, as it provides OH323_SRCDIR from openh323u.mak, which may be needed to compile some applications:
Suggests:       openh323-debugsource

%description devel
This package contains header and script files of the openh323 library
for developers.

To compile some third party projects that use files in OH323_SRCDIR, you
may need to install also openh323-debugsource package.

%prep
%setup -q -n %{name}_v%{_version}
%patch
%if %DISTRIBUTABLE == 0
%patch1
%endif
%patch2
%patch3
%patch4
%patch5 -p1
%patch6 -p1
chmod 0644 videonotes.rtf

%build
#autoreconf --force --install
autoconf --force
aclocal
cd plugins
autoconf --force
aclocal
cd ..
export CPPFLAGS="-I/usr/include/gsm"
export CCFLAGS="$RPM_OPT_FLAGS"
export OPTCCFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -fstack-protector"
# PWlib versioncheck does not work properly
# Can support Transnexus OSP Toolkit
%configure \
	--disable-versioncheck

make %{?_smp_mflags}

%install
%makeinstall
# Now edit openh323u.mak to not refer to build directories:
sed -i '
# Set prefix
/^H323_AVCODEC/i \
PREFIX\t\t     = %{_prefix}
# Do not point to build directory
s:^\(OPENH323DIR[[:space:]]*=[[:space:]]*\).*:\1%{_prefix}:
# Fix libdir
s:/lib$:/%{_lib}:g
s:/lib/:/%{_lib}/:g
# Set source reference to location, where openh323-debugsource install its data
s:\$(OPENH323DIR)/src:/usr/src/debug/%{name}_v%{_version}:
' %{buildroot}%{_datadir}/openh323/openh323u.mak

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc ChangeLog VoIPBlaster.txt mpl-1.0.htm videonotes.rtf
%{_libdir}/libh323_linux_%{arch}_r.so.*
%dir %{_libdir}/pwlib/codecs
%dir %{_libdir}/pwlib/codecs/audio
%{_libdir}/pwlib/codecs/audio/*

%files devel
%defattr(-,root,root)
%doc ReadMe.txt
%dir %{_includedir}/openh323
%{_includedir}/openh323/*
%dir %{_datadir}/openh323
%{_datadir}/openh323/*
%{_libdir}/libopenh323.so
%{_libdir}/libh323_linux_%{arch}_r.so

%changelog
* Thu Sep 26 2013 sbrabec@suse.cz
- Fix installed openh323u.mak to refer to the correct directories
  (bnc#839475#c5).
* Wed Jul 11 2012 adrian@suse.de
- fix build for armv7hl
* Thu Feb  9 2012 meissner@suse.de
- remove suse_update_config old call
* Fri Dec  9 2011 coolo@suse.com
- fix license to be in spdx.org format
* Tue Dec  6 2011 agraf@suse.com
- set arch to armv7l on arm so the package list is correct
* Fri Dec  2 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Fri Jan 15 2010 chris@computersalat.de
- cleanup spec
  o sort TAGS
  o fix Builddeps
    pwlib-devel = 1.11.0
  o macros
- rpmlint
  o spurious executable permission
  o run_ldconfig > /sbin/ldconfig
  o devel-file-in-non-devel-package
    {_libdir}/libh323_linux_x86_64_r.so
* Sun Aug  5 2007 olh@suse.de
- remove inclusion of linux/compiler.h
* Sat May 12 2007 olh@suse.de
- remove unused libavc1394-devel libdc1394-devel from Buildrequires
* Mon Feb 26 2007 kkeil@suse.de
- disable PTRACING for GetPreferedNatMethod
* Sat Oct 28 2006 meissner@suse.de
- compile speex codec with RPM_OPT_FLAGS
* Thu Sep 14 2006 sbrabec@suse.cz
- Disabled AMR-NB support in distributable build (#204767).
* Tue Aug  8 2006 sbrabec@suse.cz
- Updated to version 1.11.1:
  * More codecs.
  * Improved NAT and ToS support.
  * Compilation warning fixes.
- Fixed GSM support.
- Added system AMR-NB support.
- Disabled PWlib version check, which does not work properly.
- Enabled parallel build.
* Thu Mar  9 2006 bk@suse.de
- Use explicit gcc-c++ in BuildRequires (was implicit by SDL-devel)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 kkaempf@suse.de
- build with '-fstack-protector' to catch stack overflows
* Wed Dec 14 2005 ro@suse.de
- fix extra qualification in ixjlid.h
- make it build on 64bit
- move real library to main package (filename ends in .so ...)
* Tue Dec  6 2005 kkaempf@suse.de
- fix gcc4.1'undefined operation' warning (#136906)
* Tue Nov 22 2005 kkaempf@suse.de
- add -fno-strict-aliasing to make.
* Wed Oct 19 2005 kkaempf@suse.de
- remove 'extra qualification' for GCC 4.1.
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Tue Aug  2 2005 kkaempf@suse.de
- fix shared library installation symlinks.
* Mon Aug  1 2005 kkaempf@suse.de
- move the .so files to the -devel subpackage.
* Tue Jul 26 2005 kkaempf@suse.de
- update to 1.17.2 with lots of little fixes.
* Fri Apr  8 2005 kkaempf@suse.de
- update to 1.17.1
- some more GCC4 fixes.
* Sun Apr  3 2005 aj@suse.de
- Fix to build with GCC4.
* Tue Dec 21 2004 kkaempf@suse.de
- update to 1.15.2 (for gnomemeeting 1.2)
* Tue Aug 17 2004 kkaempf@suse.de
- update to 1.15.0
* Mon Mar 22 2004 kkaempf@suse.de
- update to 1.13.4, dropping all SUSE patches
  (they're included now !)
- fix typo in src/Makefile
* Mon Mar  8 2004 ro@suse.de
- added libdc1394-devel to neededforbuild
* Thu Mar  4 2004 kkaempf@suse.de
- update to final 1.13.2
* Wed Feb 25 2004 kkaempf@suse.de
- better fix for the "-fPIC" problem
* Wed Feb 25 2004 ro@suse.de
- re-add fPIC where needed
* Sun Feb 22 2004 kkaempf@suse.de
- fix lib64 in build environment
* Sun Feb 22 2004 kkaempf@suse.de
- update to 1.13.2pre1
- use speex package, not builtin code
* Fri Jan  9 2004 adrian@suse.de
- add %%run_ldconfig
* Fri Jul 18 2003 kkaempf@suse.de
- update to 1.12.2 (from CVS, as advised on openh323 mailing list)
- fix %%build in specfile, openh323 uses autoconf/automake now
- install libraries to %%libdir,
  install includes to /usr/include/openh323,
  install shared files to /usr/share/openh323
- added support for ieee1394 (Firewire) cameras
- enable IPv6 (untested)
* Fri Feb  7 2003 kkaempf@suse.de
- disable IPv6, it's still experimental.
* Thu Feb  6 2003 kkaempf@suse.de
- update to 1.11.5
* Fri Jan 24 2003 meissner@suse.de
- handle ppc64 correctly.
* Fri Jan 10 2003 kkaempf@suse.de
- update to 1.11.2
* Mon Dec 16 2002 kkaempf@suse.de
- update to 1.11.1
  added H.248 support
  Added basic infrastructure for Annex K/H.323 HTTP transport system.
  Added Call Credit Service Control to display account balances.
* Fri Nov 15 2002 kkaempf@suse.de
- add expat to support openivr package
- fix 64bit portability bug in speex (ptr->int cast)
- update to 1.10.4
* Fri Nov 15 2002 schwab@suse.de
- Fix missing -fPIC.
- Fix conflicting type of strndup.
* Wed Nov 13 2002 kkaempf@suse.de
- update to 1.10.3
* Mon Nov 11 2002 ro@suse.de
- fix typo in specfile
* Thu Nov  7 2002 ro@suse.de
- install speex.h and speex_bits.h
* Thu Nov  7 2002 ro@suse.de
- update to current 1.10.2
* Sat Aug 17 2002 kkaempf@suse.de
- Update to 1.9.5:
  Changes to the RAS subsystem to support ability to make requests to client
    from gkserver without causing bottlenecks and race conditions.
  Fairly major modifications to support different authentication credentials
    in ARQ to the logged in ones on RRQ. For both client and server.
    Various other H.235 authentication bugs and anomalies fixed on the way.
  Added Speex codec detection
* Tue Aug  6 2002 kkaempf@suse.de
- Update to 1.9.4
* Thu Jul 11 2002 kkaempf@suse.de
- update to 1.9.3
- implements T.38 modem and fax capabilities.
* Wed Jun 26 2002 ro@suse.de
- use -fPIC for all files to be included in shared lib
* Tue Jun 18 2002 meissner@suse.de
- Use -mminimal-toc on ppc64 (for now). propagata RPM_OPT_FLAGS into
  make.
* Wed May 22 2002 ro@suse.de
- update to 1.8.8
* Thu Apr 18 2002 schwab@suse.de
- Fix variable references in makefile.
* Thu Apr 18 2002 ro@suse.de
- update to 1.8.5
* Wed Jan 30 2002 kkaempf@suse.de
- Update to 1.7.10
* Wed Jan  2 2002 kkaempf@suse.de
- enable cu30 codec
* Wed Jan  2 2002 adrian@suse.de
- using $RPM_OPT_FLAGS
- use -xgot assembler option on mips to fix linking
* Tue Dec 18 2001 kkaempf@suse.de
- Update to 1.7.8
- Use %%{_libdir} in Makefiles
* Mon Dec 17 2001 kkaempf@suse.de
- Update to 1.7.7
- Adapt .spec file to %%{_libdir}
* Mon Aug 27 2001 kkaempf@suse.de
- remove unneccessary assertion call in h323caps.cxx
* Fri Aug 17 2001 kkaempf@suse.de
- update to 1.6.0
  see www.openh323.org for details
* Thu Aug 16 2001 kkaempf@suse.de
- implement RPM_BUILD_ROOT in spec file.
* Tue Aug  7 2001 kkaempf@suse.de
- add openssl and openssl-devel to neededforbuild
* Mon Aug  6 2001 kkaempf@suse.de
- update to 1.5.6
* Wed Mar  7 2001 uli@suse.de
- added xf86 to neededforbuild
* Thu Feb  8 2001 kkaempf@suse.de
- define timerclear for ixjunix.cxx, its a gnu extension
* Thu Jan  4 2001 kkaempf@suse.de
- provide .so file in -devel package only
* Wed Jan  3 2001 kkaempf@suse.de
- move files from /opt/h323/openh323 to /usr/lib/openh323
  install libraries in /usr/lib
  install development components in /usr/lib/openh323
* Tue Jan  2 2001 kkaempf@suse.de
- update to maintenance release 1.1pl1
* Thu Nov 16 2000 kkaempf@suse.de
- use %%doc in specfile
* Wed Nov 15 2000 kkaempf@suse.de
- split off -devel package
  provide Readme.txt
* Thu Nov  9 2000 kkaempf@suse.de
- update to 1.1 release version
* Fri Jul 14 2000 kkaempf@suse.de
- cvs update, fix race condition
* Fri Jul 14 2000 kkaempf@suse.de
- fix LDFLAGS for X11
  cvs update, fix GSM codec
* Thu Jul 13 2000 kkaempf@suse.de
- cvs update, faststart fix
* Wed Jul 12 2000 kkaempf@suse.de
- fix sparc machtype
* Wed Jul 12 2000 kkaempf@suse.de
- cvs update
  fix specfile for sparc
* Mon Jul 10 2000 kkaempf@suse.de
- fix specfile for alpha and ia64
* Tue Jul  4 2000 kkaempf@suse.de
- Seperated video receive and transmit options
  Added ability for video to work on 24, 16 and 8 bit visuals
* Mon Jul  3 2000 kkaempf@suse.de
- fix audio deadlock
* Mon Jun 26 2000 kkaempf@suse.de
- fix libname for alpha
* Wed Jun 21 2000 kkaempf@suse.de
- include toplevel make template in filelist
* Wed Jun 21 2000 kkaempf@suse.de
- adapt to non-x86 architectures
* Tue Jun 20 2000 kkaempf@suse.de
- update to newest CVS version
  fixed specfile
* Tue Jun 20 2000 kkaempf@suse.de
- created package
